@@ -609,7 +609,7 @@ void Component::mirrorX() {
     QFont f = QucsSettings.font;
     // mirror all text
     for (Text *pt: Texts) {
-        f.setPointSizeF(pt->Size);
+        f.setPixelSize(pt->Size);
         // use the screen-compatible metric
         QFontMetrics smallMetrics(f, 0);
         QSize s = smallMetrics.size(0, pt->s);   // use size for more lines
@@ -677,7 +677,7 @@ void Component::mirrorY() {
     QFont f = QucsSettings.font;
     // mirror all text
     for (Text *pt: Texts) {
-        f.setPointSizeF(pt->Size);
+        f.setPixelSize(pt->Size);
         // use the screen-compatible metric
         QFontMetrics smallMetrics(f, 0);
         QSize s = smallMetrics.size(0, pt->s);   // use size for more lines
@@ -758,7 +758,11 @@ QString Component::form_spice_param_list(QStringList &ignore_list, QStringList &
     return par_str;
 }
 
-QString Component::spice_netlist(bool) {
+QString Component::spice_netlist(spicecompat::SpiceDialect) {
+    return QStringLiteral("\n"); // ignore if not implemented
+}
+
+QString Component::cdl_netlist() {
     return QStringLiteral("\n"); // ignore if not implemented
 }
 
@@ -787,11 +791,11 @@ QString Component::getNetlist() {
     return s;
 }
 
-QString Component::getSpiceNetlist(bool isXyce) {
+QString Component::getSpiceNetlist(spicecompat::SpiceDialect dialect /* = SPICEDefault */) {
     QString s;
     switch (isActive) {
         case COMP_IS_ACTIVE:
-            s = spice_netlist(isXyce);
+            s = dialect == spicecompat::CDL ? cdl_netlist() : spice_netlist(dialect);
             s.replace(" gnd ", " 0 ");
             return s;
         case COMP_IS_OPEN:
@@ -804,9 +808,9 @@ QString Component::getSpiceNetlist(bool isXyce) {
     Port *pp = iport.next();
     QString Node1 = pp->Connection->Name;
     s = "";
-    while (iport.hasNext())
+    while (iport.hasNext()) // Add minR resistors
         s += "R" + Name + QString::number(z++) + " " +
-             Node1 + " " + iport.next()->Connection->Name + " 0\n";
+             Node1 + " " + iport.next()->Connection->Name + " 1e-12\n";
 
     s.replace(" gnd ", " 0 ");
     return s;
@@ -824,7 +828,7 @@ QString Component::getVerilogACode() {
     }
 }
 
-QString Component::getExpression(bool) {
+QString Component::getExpression(spicecompat::SpiceDialect) {
     return QString();
 }
 
@@ -836,7 +840,7 @@ QStringList Component::getExtraVariables() {
     return QStringList();
 }
 
-QString Component::getProbeVariable(bool) {
+QString Component::getProbeVariable(spicecompat::SpiceDialect) {
     return QString();
 }
 
@@ -1465,7 +1469,7 @@ void Component::copyComponent(Component *pc) {
 // ***********************************************************************
 void MultiViewComponent::recreate(Schematic *Doc) {
     if (Doc) {
-        Doc->Components->setAutoDelete(false);
+        Doc->a_Components->setAutoDelete(false);
         Doc->deleteComp(this);
     }
 
@@ -1493,7 +1497,7 @@ void MultiViewComponent::recreate(Schematic *Doc) {
 
     if (Doc) {
         Doc->insertRawComponent(this);
-        Doc->Components->setAutoDelete(true);
+        Doc->a_Components->setAutoDelete(true);
     }
 }
 
@@ -1537,8 +1541,11 @@ QString GateComponent::netlist() {
     return s;
 }
 
-QString GateComponent::spice_netlist(bool isXyce) {
-    if (isXyce) return {""};
+QString GateComponent::spice_netlist(spicecompat::SpiceDialect dialect) {
+    if (dialect == spicecompat::SPICEXyce)
+    {
+        return QString();
+    }
 
     QString s = SpiceModel + Name;
     QString tmp_model = "model_" + Name;
