@@ -574,9 +574,14 @@ void QucsApp::initActions()
 
   save_netlist = new QAction(tr("Save netlist"), this);
   save_netlist->setStatusTip(tr("Save netlist"));
-  save_netlist->setWhatsThis(tr("Save netlist to file"));
+  save_netlist->setWhatsThis(tr(QString::fromUtf8("Save netlist to %1").arg(a_netlist2Console ? "console" : "file").toLatin1().constData()));
   connect(save_netlist, SIGNAL(triggered()), SLOT(slotSaveNetlist()));
 
+  saveCdlNetlist = new QAction(tr("Save CDL netlist"), this);
+  saveCdlNetlist->setStatusTip(tr("Save CDL netlist"));
+  saveCdlNetlist->setWhatsThis(tr(QString::fromUtf8("Save CDL netlist to %1").arg(a_netlist2Console ? "console" : "file").toLatin1().constData()));
+  connect(saveCdlNetlist, SIGNAL(triggered()), SLOT(slotSaveCdlNetlist()));
+
   setMarker = new QAction(QIcon((":/bitmaps/svg/marker.svg")),	tr("Set Marker on Graph"), this);
   setMarker->setShortcut(Qt::CTRL|Qt::Key_B);
   setMarker->setStatusTip(tr("Sets a marker on a diagram's graph"));
@@ -597,6 +602,13 @@ void QucsApp::initActions()
   resetDiagramLimits->setWhatsThis(tr("Reset Diagram Limits\n\nResets the limits for all axis to auto."));
   connect(resetDiagramLimits, SIGNAL(triggered()), SLOT(slotResetDiagramLimits()));
 
+  showGrid = new QAction(tr("Show Grid (current document)"), this);
+  showGrid->setCheckable(true);
+  showGrid->setShortcut(tr("Alt+G"));
+  showGrid->setStatusTip(tr("Show or hide the grid for the current document."));
+  showGrid->setWhatsThis(tr("Show / Hide Grid\n\nShow or hide the grid for the current document."));
+  connect(showGrid, SIGNAL(triggered()), SLOT(slotShowGrid()));
+
   showMsg = new QAction(tr("Show Last Messages"), this);
   showMsg->setShortcut(Qt::Key_F5);
   showMsg->setStatusTip(tr("Shows last simulation messages"));
@@ -789,6 +801,7 @@ void QucsApp::initMenuBar()
   simMenu->addAction(showMsg);
   simMenu->addAction(showNet);
   simMenu->addAction(save_netlist);
+  simMenu->addAction(saveCdlNetlist);
   simMenu->addAction(simSettings);
 
 
@@ -800,7 +813,9 @@ void QucsApp::initMenuBar()
   viewMenu->addAction(magMinus);
   viewMenu->addAction(setDiagramLimits);
   viewMenu->addSeparator();
-  //viewMenu->setCheckable(true);
+  viewMenu->addAction(showGrid);
+  viewMenu->addSeparator();
+    //viewMenu->setCheckable(true);
   viewMenu->addAction(viewBrowseDock);
   viewMenu->addAction(viewOctaveDock);
 
