@@ -31,7 +31,7 @@ public:
   static Element* info(QString&, char* &, bool getNewOne=false);
 protected:
   QString netlist();
-  QString spice_netlist(bool isXyce = false);
+  QString spice_netlist(spicecompat::SpiceDialect dialect = spicecompat::SPICEDefault);
 };
 
 #endif // core_H
