@@ -34,7 +34,7 @@
 #include <float.h>
 #include <ctype.h>
 
-#if defined(_WIN32) & not defined(__MINGW32__)
+#if defined(_WIN32) && defined(_MSC_VER)
 #define strcasecmp stricmp
 #endif
 
